summaryrefslogtreecommitdiffstats
path: root/perl-install/lang.pm
diff options
context:
space:
mode:
authorFrancois Pons <fpons@mandriva.com>2000-08-24 15:57:23 +0000
committerFrancois Pons <fpons@mandriva.com>2000-08-24 15:57:23 +0000
commit328ce33d9b48588abd507591d403ffcdf9612a93 (patch)
tree376572183d1ad3ac56718f5a21b08d721c7486f4 /perl-install/lang.pm
parentae6724e80a75c2e253daa9ded045c756f399e860 (diff)
downloaddrakx-backup-do-not-use-328ce33d9b48588abd507591d403ffcdf9612a93.tar
drakx-backup-do-not-use-328ce33d9b48588abd507591d403ffcdf9612a93.tar.gz
drakx-backup-do-not-use-328ce33d9b48588abd507591d403ffcdf9612a93.tar.bz2
drakx-backup-do-not-use-328ce33d9b48588abd507591d403ffcdf9612a93.tar.xz
drakx-backup-do-not-use-328ce33d9b48588abd507591d403ffcdf9612a93.zip
*** empty log message ***
Diffstat (limited to 'perl-install/lang.pm')
-rw-r--r--perl-install/lang.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/perl-install/lang.pm b/perl-install/lang.pm
index 490cdee57..f5777151d 100644
--- a/perl-install/lang.pm
+++ b/perl-install/lang.pm
@@ -217,7 +217,7 @@ sub set {
my ($lang) = @_;
if ($lang && $languages{$lang}) {
#- use extract_archive that follow symlinks and expand directory.
#- it is necessary as there is a lot of symlinks inside locale.cz2,
#- using a compressed cpio archive is nighmare to extract all files.
#- reset locale environment variable to avoid any warnings by perl,
@@ -227,7 +227,7 @@ sub set {
eval { commands::rm("-r", "$ENV{SHARE_PATH}/locale") };
require 'run_program.pm';
- run_program::run("extract_archive", "$ENV{SHARE_PATH}/locale.cz2", "$ENV{SHARE_PATH}/locale", $languages{$lang}[2]);
+ run_program::run("packdrake", "-x", "$ENV{SHARE_PATH}/locale.cz2", "$ENV{SHARE_PATH}/locale", $languages{$lang}[2]);
}
$ENV{LC_ALL} = $lang;
@@ -321,7 +321,7 @@ sub load_po($) {
} else {
-e ($f = "$_/po.cz2") and last foreach @INC;
log::l("trying to load $lang.po from $f");
- open F, "extract_archive $f '' $lang.po 2>/dev/null |";
+ open F, "packdrake -x $f '' $lang.po 2>/dev/null |";
}
} else {
open F, $f; #- not returning here help avoiding reading the same multiple times.
@@ -217,7 +217,7 @@ sub set {
my ($lang) = @_;
if ($lang && $languages{$lang}) {
- #- use extract_archive that follow symlinks and expand directory.
+ #- use "packdrake -x" that follow symlinks and expand directory.
#- it is necessary as there is a lot of symlinks inside locale.cz2,
#- using a compressed cpio archive is nighmare to extract all files.